@@ -1,5 +1,3 @@
-from pyramid.response import Response
-
 from clld.interfaces import IOlacConfig
 from clld.web.views.olac import OlacConfig, Participant, Institution
 
@@ -12,7 +10,7 @@ class MpgOlacConfig(OlacConfig):
         res = OlacConfig.description(self, req)
         res['institution'] = Institution(
             'Max Planck Institute for Evolutionary Anthropology',
-            'http://www.eva.mpg.de',
+            'https://www.eva.mpg.de',
             'Leipzig, Germany')
         return res
 
@@ -24,7 +22,3 @@ def includeme(config):
     config.add_settings({'clld.publisher_logo': 'clldmpg:static/minerva.png'})
     config.add_settings(
         {'clld.privacy_policy_url': 'https://www.eva.mpg.de/privacy-policy.html'})
-    config.add_route('google-site-verification', 'googlebbc8f4da1abdc58b.html')
-    config.add_view(
-        lambda r: Response('google-site-verification: googlebbc8f4da1abdc58b.html'),
-        route_name='google-site-verification')
